from distutils.core import setup
setup(
  name = 'Topsis_Abhay_102016081',         
  packages = ['Topsis_Abhay_102016081'],   
  version = '0.1',      
  license='MIT',        
  description = 'A topsis score calculator', 
  
  
  author = 'Abhay bedi',                   
  author_email = 'abhaybedi68@gmail.com',     
  
  keywords = ['topsis'],   
  install_requires=[           
          'numpy',
          'pandas',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',     
    'Intended Audience :: Developers',      
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   
    'Programming Language :: Python :: 3',      
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
  ],
)